@@ -13,7 +13,8 @@ class Main:
     @staticmethod
     def parse_args():
         parser = argparse.ArgumentParser(
-            description="Spud: The plugin manager for your Spigot Minecraft server"
+            description="Spud: The plugin manager for your Spigot Minecraft server",
+            epilog="Licensed under GPLv3 (https://www.gnu.org/licenses/gpl-3.0.en.html)",
         )
         parser.add_argument("action", help="install or update", type=str)
         parser.add_argument(
@@ -23,6 +24,13 @@ class Main:
             type=str,
             nargs="*",
         )
+        parser.add_argument(
+            "-n",
+            dest="noninteractive",
+            help="run without asking for input",
+            action="store_true",
+            default=False,
+        )
         parser.add_argument(
             "-d",
             "--directory",
@@ -69,8 +77,18 @@ class Main:
 
                 plugin_list = self.spiget_api.search_plugins(plugin_name)
 
+                if not plugin_list:
+                    Utils.error(
+                        f"No plugin with name {plugin_name} found.", fatal=False
+                    )
+                    continue
+
                 Utils.status_good(f"Query: {plugin_name}")
-                plugin = self.get_plugin_choice(plugin_list)
+
+                if args.noninteractive:
+                    plugin = plugin_list[0]
+                else:
+                    plugin = self.get_plugin_choice(plugin_list)
 
                 if not plugin:
                     Utils.warning("Skipping!")
